# Python tools for ORCESTRA campaign

## install

The latest released version can be installed using:

```
pip install orcestra
```

## developing

This project uses [ruff](https://github.com/astral-sh/ruff) for code formatting and [pre-commit](https://pre-commit.com/) to run the formatter automatically.

Please ensure that you have `pre-commit` configured locally by running:

```
pre-commit install
```
